# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/user_account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/organizationmanager/v1/user_account.proto',
  package='yandex.cloud.organizationmanager.v1',
  syntax='proto3',
  serialized_options=b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6yandex/cloud/organizationmanager/v1/user_account.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1dyandex/cloud/validation.proto\"\xea\x01\n\x0bUserAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x66\n\x1cyandex_passport_user_account\x18\x02 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.YandexPassportUserAccountH\x00\x12Q\n\x11saml_user_account\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.organizationmanager.v1.SamlUserAccountH\x00\x42\x14\n\x0cuser_account\x12\x04\xc0\xc1\x31\x01\"A\n\x19YandexPassportUserAccount\x12\r\n\x05login\x18\x01 \x01(\t\x12\x15\n\rdefault_email\x18\x02 \x01(\t\"\xbf\x02\n\x0fSamlUserAccount\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x07name_id\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-256\x12X\n\nattributes\x18\x03 \x03(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.SamlUserAccount.AttributesEntry\x1a\x1a\n\tAttribute\x12\r\n\x05value\x18\x01 \x03(\t\x1aq\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12M\n\x05value\x18\x02 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.SamlUserAccount.Attribute:\x02\x38\x01\x42\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_USERACCOUNT = _descriptor.Descriptor(
  name='UserAccount',
  full_name='yandex.cloud.organizationmanager.v1.UserAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.organizationmanager.v1.UserAccount.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yandex_passport_user_account', full_name='yandex.cloud.organizationmanager.v1.UserAccount.yandex_passport_user_account', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saml_user_account', full_name='yandex.cloud.organizationmanager.v1.UserAccount.saml_user_account', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='user_account', full_name='yandex.cloud.organizationmanager.v1.UserAccount.user_account',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=127,
  serialized_end=361,
)


_YANDEXPASSPORTUSERACCOUNT = _descriptor.Descriptor(
  name='YandexPassportUserAccount',
  full_name='yandex.cloud.organizationmanager.v1.YandexPassportUserAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='login', full_name='yandex.cloud.organizationmanager.v1.YandexPassportUserAccount.login', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_email', full_name='yandex.cloud.organizationmanager.v1.YandexPassportUserAccount.default_email', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=428,
)


_SAMLUSERACCOUNT_ATTRIBUTE = _descriptor.Descriptor(
  name='Attribute',
  full_name='yandex.cloud.organizationmanager.v1.SamlUserAccount.Attribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.organizationmanager.v1.SamlUserAccount.Attribute.value', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=635,
)

_SAMLUSERACCOUNT_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='yandex.cloud.organizationmanager.v1.SamlUserAccount.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.organizationmanager.v1.SamlUserAccount.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.organizationmanager.v1.SamlUserAccount.AttributesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=750,
)

_SAMLUSERACCOUNT = _descriptor.Descriptor(
  name='SamlUserAccount',
  full_name='yandex.cloud.organizationmanager.v1.SamlUserAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.SamlUserAccount.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name_id', full_name='yandex.cloud.organizationmanager.v1.SamlUserAccount.name_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\0051-256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='yandex.cloud.organizationmanager.v1.SamlUserAccount.attributes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SAMLUSERACCOUNT_ATTRIBUTE, _SAMLUSERACCOUNT_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=750,
)

_USERACCOUNT.fields_by_name['yandex_passport_user_account'].message_type = _YANDEXPASSPORTUSERACCOUNT
_USERACCOUNT.fields_by_name['saml_user_account'].message_type = _SAMLUSERACCOUNT
_USERACCOUNT.oneofs_by_name['user_account'].fields.append(
  _USERACCOUNT.fields_by_name['yandex_passport_user_account'])
_USERACCOUNT.fields_by_name['yandex_passport_user_account'].containing_oneof = _USERACCOUNT.oneofs_by_name['user_account']
_USERACCOUNT.oneofs_by_name['user_account'].fields.append(
  _USERACCOUNT.fields_by_name['saml_user_account'])
_USERACCOUNT.fields_by_name['saml_user_account'].containing_oneof = _USERACCOUNT.oneofs_by_name['user_account']
_SAMLUSERACCOUNT_ATTRIBUTE.containing_type = _SAMLUSERACCOUNT
_SAMLUSERACCOUNT_ATTRIBUTESENTRY.fields_by_name['value'].message_type = _SAMLUSERACCOUNT_ATTRIBUTE
_SAMLUSERACCOUNT_ATTRIBUTESENTRY.containing_type = _SAMLUSERACCOUNT
_SAMLUSERACCOUNT.fields_by_name['attributes'].message_type = _SAMLUSERACCOUNT_ATTRIBUTESENTRY
DESCRIPTOR.message_types_by_name['UserAccount'] = _USERACCOUNT
DESCRIPTOR.message_types_by_name['YandexPassportUserAccount'] = _YANDEXPASSPORTUSERACCOUNT
DESCRIPTOR.message_types_by_name['SamlUserAccount'] = _SAMLUSERACCOUNT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserAccount = _reflection.GeneratedProtocolMessageType('UserAccount', (_message.Message,), {
  'DESCRIPTOR' : _USERACCOUNT,
  '__module__' : 'yandex.cloud.organizationmanager.v1.user_account_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.UserAccount)
  })
_sym_db.RegisterMessage(UserAccount)

YandexPassportUserAccount = _reflection.GeneratedProtocolMessageType('YandexPassportUserAccount', (_message.Message,), {
  'DESCRIPTOR' : _YANDEXPASSPORTUSERACCOUNT,
  '__module__' : 'yandex.cloud.organizationmanager.v1.user_account_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.YandexPassportUserAccount)
  })
_sym_db.RegisterMessage(YandexPassportUserAccount)

SamlUserAccount = _reflection.GeneratedProtocolMessageType('SamlUserAccount', (_message.Message,), {

  'Attribute' : _reflection.GeneratedProtocolMessageType('Attribute', (_message.Message,), {
    'DESCRIPTOR' : _SAMLUSERACCOUNT_ATTRIBUTE,
    '__module__' : 'yandex.cloud.organizationmanager.v1.user_account_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.SamlUserAccount.Attribute)
    })
  ,

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SAMLUSERACCOUNT_ATTRIBUTESENTRY,
    '__module__' : 'yandex.cloud.organizationmanager.v1.user_account_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.SamlUserAccount.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _SAMLUSERACCOUNT,
  '__module__' : 'yandex.cloud.organizationmanager.v1.user_account_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.SamlUserAccount)
  })
_sym_db.RegisterMessage(SamlUserAccount)
_sym_db.RegisterMessage(SamlUserAccount.Attribute)
_sym_db.RegisterMessage(SamlUserAccount.AttributesEntry)


DESCRIPTOR._options = None
_USERACCOUNT.oneofs_by_name['user_account']._options = None
_SAMLUSERACCOUNT_ATTRIBUTESENTRY._options = None
_SAMLUSERACCOUNT.fields_by_name['federation_id']._options = None
_SAMLUSERACCOUNT.fields_by_name['name_id']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/dataproc/manager/v1/job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/dataproc/manager/v1/job.proto',
  package='yandex.cloud.dataproc.manager.v1',
  syntax='proto3',
  serialized_options=b'\n$yandex.cloud.api.dataproc.manager.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/manager/v1;dataproc_manager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/dataproc/manager/v1/job.proto\x12 yandex.cloud.dataproc.manager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe0\x05\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x12\n\ncreated_by\x18\x0c \x01(\t\x12<\n\x06status\x18\x07 \x01(\x0e\x32,.yandex.cloud.dataproc.manager.v1.Job.Status\x12G\n\rmapreduce_job\x18\x08 \x01(\x0b\x32..yandex.cloud.dataproc.manager.v1.MapreduceJobH\x00\x12?\n\tspark_job\x18\t \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.SparkJobH\x00\x12\x43\n\x0bpyspark_job\x18\n \x01(\x0b\x32,.yandex.cloud.dataproc.manager.v1.PysparkJobH\x00\x12=\n\x08hive_job\x18\x0b \x01(\x0b\x32).yandex.cloud.dataproc.manager.v1.HiveJobH\x00\x12K\n\x10\x61pplication_info\x18\r \x01(\x0b\x32\x31.yandex.cloud.dataproc.manager.v1.ApplicationInfo\"a\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x08\n\x04\x44ONE\x10\x05\x42\n\n\x08job_spec\"9\n\x12\x41pplicationAttempt\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0f\x61m_container_id\x18\x02 \x01(\t\"q\n\x0f\x41pplicationInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12R\n\x14\x61pplication_attempts\x18\x02 \x03(\x0b\x32\x34.yandex.cloud.dataproc.manager.v1.ApplicationAttempt\"\xa0\x02\n\x0cMapreduceJob\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x14\n\x0c\x61rchive_uris\x18\x04 \x03(\t\x12R\n\nproperties\x18\x05 \x03(\x0b\x32>.yandex.cloud.dataproc.manager.v1.MapreduceJob.PropertiesEntry\x12\x1b\n\x11main_jar_file_uri\x18\x06 \x01(\tH\x00\x12\x14\n\nmain_class\x18\x07 \x01(\tH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06\x64river\"\x8a\x02\n\x08SparkJob\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x14\n\x0c\x61rchive_uris\x18\x04 \x03(\t\x12N\n\nproperties\x18\x05 \x03(\x0b\x32:.yandex.cloud.dataproc.manager.v1.SparkJob.PropertiesEntry\x12\x19\n\x11main_jar_file_uri\x18\x06 \x01(\t\x12\x12\n\nmain_class\x18\x07 \x01(\t\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x02\n\nPysparkJob\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x14\n\x0c\x61rchive_uris\x18\x04 \x03(\t\x12P\n\nproperties\x18\x05 \x03(\x0b\x32<.yandex.cloud.dataproc.manager.v1.PysparkJob.PropertiesEntry\x12\x1c\n\x14main_python_file_uri\x18\x06 \x01(\t\x12\x18\n\x10python_file_uris\x18\x07 \x03(\t\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1c\n\tQueryList\x12\x0f\n\x07queries\x18\x01 \x03(\t\"\xbc\x03\n\x07HiveJob\x12M\n\nproperties\x18\x01 \x03(\x0b\x32\x39.yandex.cloud.dataproc.manager.v1.HiveJob.PropertiesEntry\x12\x1b\n\x13\x63ontinue_on_failure\x18\x02 \x01(\x08\x12X\n\x10script_variables\x18\x03 \x03(\x0b\x32>.yandex.cloud.dataproc.manager.v1.HiveJob.ScriptVariablesEntry\x12\x15\n\rjar_file_uris\x18\x04 \x03(\t\x12\x18\n\x0equery_file_uri\x18\x05 \x01(\tH\x00\x12\x41\n\nquery_list\x18\x06 \x01(\x0b\x32+.yandex.cloud.dataproc.manager.v1.QueryListH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14ScriptVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\nquery_typeB}\n$yandex.cloud.api.dataproc.manager.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/manager/v1;dataproc_managerb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_JOB_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.dataproc.manager.v1.Job.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROVISIONING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=741,
  serialized_end=838,
)
_sym_db.RegisterEnumDescriptor(_JOB_STATUS)


_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='yandex.cloud.dataproc.manager.v1.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.dataproc.manager.v1.Job.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.manager.v1.Job.cluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.dataproc.manager.v1.Job.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='yandex.cloud.dataproc.manager.v1.Job.started_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finished_at', full_name='yandex.cloud.dataproc.manager.v1.Job.finished_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dataproc.manager.v1.Job.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='yandex.cloud.dataproc.manager.v1.Job.created_by', index=6,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.dataproc.manager.v1.Job.status', index=7,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapreduce_job', full_name='yandex.cloud.dataproc.manager.v1.Job.mapreduce_job', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spark_job', full_name='yandex.cloud.dataproc.manager.v1.Job.spark_job', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pyspark_job', full_name='yandex.cloud.dataproc.manager.v1.Job.pyspark_job', index=10,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hive_job', full_name='yandex.cloud.dataproc.manager.v1.Job.hive_job', index=11,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_info', full_name='yandex.cloud.dataproc.manager.v1.Job.application_info', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _JOB_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='job_spec', full_name='yandex.cloud.dataproc.manager.v1.Job.job_spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=114,
  serialized_end=850,
)


_APPLICATIONATTEMPT = _descriptor.Descriptor(
  name='ApplicationAttempt',
  full_name='yandex.cloud.dataproc.manager.v1.ApplicationAttempt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.dataproc.manager.v1.ApplicationAttempt.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='am_container_id', full_name='yandex.cloud.dataproc.manager.v1.ApplicationAttempt.am_container_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=909,
)


_APPLICATIONINFO = _descriptor.Descriptor(
  name='ApplicationInfo',
  full_name='yandex.cloud.dataproc.manager.v1.ApplicationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.dataproc.manager.v1.ApplicationInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_attempts', full_name='yandex.cloud.dataproc.manager.v1.ApplicationInfo.application_attempts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=911,
  serialized_end=1024,
)


_MAPREDUCEJOB_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yandex.cloud.dataproc.manager.v1.MapreduceJob.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.dataproc.manager.v1.MapreduceJob.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.dataproc.manager.v1.MapreduceJob.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1305,
)

_MAPREDUCEJOB = _descriptor.Descriptor(
  name='MapreduceJob',
  full_name='yandex.cloud.dataproc.manager.v1.MapreduceJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='args', full_name='yandex.cloud.dataproc.manager.v1.MapreduceJob.args', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jar_file_uris', full_name='yandex.cloud.dataproc.manager.v1.MapreduceJob.jar_file_uris', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_uris', full_name='yandex.cloud.dataproc.manager.v1.MapreduceJob.file_uris', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='archive_uris', full_name='yandex.cloud.dataproc.manager.v1.MapreduceJob.archive_uris', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yandex.cloud.dataproc.manager.v1.MapreduceJob.properties', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_jar_file_uri', full_name='yandex.cloud.dataproc.manager.v1.MapreduceJob.main_jar_file_uri', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_class', full_name='yandex.cloud.dataproc.manager.v1.MapreduceJob.main_class', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MAPREDUCEJOB_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='driver', full_name='yandex.cloud.dataproc.manager.v1.MapreduceJob.driver',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1027,
  serialized_end=1315,
)


_SPARKJOB_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yandex.cloud.dataproc.manager.v1.SparkJob.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.dataproc.manager.v1.SparkJob.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.dataproc.manager.v1.SparkJob.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1305,
)

_SPARKJOB = _descriptor.Descriptor(
  name='SparkJob',
  full_name='yandex.cloud.dataproc.manager.v1.SparkJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='args', full_name='yandex.cloud.dataproc.manager.v1.SparkJob.args', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jar_file_uris', full_name='yandex.cloud.dataproc.manager.v1.SparkJob.jar_file_uris', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_uris', full_name='yandex.cloud.dataproc.manager.v1.SparkJob.file_uris', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='archive_uris', full_name='yandex.cloud.dataproc.manager.v1.SparkJob.archive_uris', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yandex.cloud.dataproc.manager.v1.SparkJob.properties', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_jar_file_uri', full_name='yandex.cloud.dataproc.manager.v1.SparkJob.main_jar_file_uri', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_class', full_name='yandex.cloud.dataproc.manager.v1.SparkJob.main_class', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SPARKJOB_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1318,
  serialized_end=1584,
)


_PYSPARKJOB_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yandex.cloud.dataproc.manager.v1.PysparkJob.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.dataproc.manager.v1.PysparkJob.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.dataproc.manager.v1.PysparkJob.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1305,
)

_PYSPARKJOB = _descriptor.Descriptor(
  name='PysparkJob',
  full_name='yandex.cloud.dataproc.manager.v1.PysparkJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='args', full_name='yandex.cloud.dataproc.manager.v1.PysparkJob.args', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jar_file_uris', full_name='yandex.cloud.dataproc.manager.v1.PysparkJob.jar_file_uris', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_uris', full_name='yandex.cloud.dataproc.manager.v1.PysparkJob.file_uris', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='archive_uris', full_name='yandex.cloud.dataproc.manager.v1.PysparkJob.archive_uris', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yandex.cloud.dataproc.manager.v1.PysparkJob.properties', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_python_file_uri', full_name='yandex.cloud.dataproc.manager.v1.PysparkJob.main_python_file_uri', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='python_file_uris', full_name='yandex.cloud.dataproc.manager.v1.PysparkJob.python_file_uris', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PYSPARKJOB_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1587,
  serialized_end=1866,
)


_QUERYLIST = _descriptor.Descriptor(
  name='QueryList',
  full_name='yandex.cloud.dataproc.manager.v1.QueryList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queries', full_name='yandex.cloud.dataproc.manager.v1.QueryList.queries', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1868,
  serialized_end=1896,
)


_HIVEJOB_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yandex.cloud.dataproc.manager.v1.HiveJob.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.dataproc.manager.v1.HiveJob.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.dataproc.manager.v1.HiveJob.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1305,
)

_HIVEJOB_SCRIPTVARIABLESENTRY = _descriptor.Descriptor(
  name='ScriptVariablesEntry',
  full_name='yandex.cloud.dataproc.manager.v1.HiveJob.ScriptVariablesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.dataproc.manager.v1.HiveJob.ScriptVariablesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.dataproc.manager.v1.HiveJob.ScriptVariablesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2275,
  serialized_end=2329,
)

_HIVEJOB = _descriptor.Descriptor(
  name='HiveJob',
  full_name='yandex.cloud.dataproc.manager.v1.HiveJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='properties', full_name='yandex.cloud.dataproc.manager.v1.HiveJob.properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_on_failure', full_name='yandex.cloud.dataproc.manager.v1.HiveJob.continue_on_failure', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='script_variables', full_name='yandex.cloud.dataproc.manager.v1.HiveJob.script_variables', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jar_file_uris', full_name='yandex.cloud.dataproc.manager.v1.HiveJob.jar_file_uris', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_file_uri', full_name='yandex.cloud.dataproc.manager.v1.HiveJob.query_file_uri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_list', full_name='yandex.cloud.dataproc.manager.v1.HiveJob.query_list', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HIVEJOB_PROPERTIESENTRY, _HIVEJOB_SCRIPTVARIABLESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='query_type', full_name='yandex.cloud.dataproc.manager.v1.HiveJob.query_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1899,
  serialized_end=2343,
)

_JOB.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name['finished_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name['status'].enum_type = _JOB_STATUS
_JOB.fields_by_name['mapreduce_job'].message_type = _MAPREDUCEJOB
_JOB.fields_by_name['spark_job'].message_type = _SPARKJOB
_JOB.fields_by_name['pyspark_job'].message_type = _PYSPARKJOB
_JOB.fields_by_name['hive_job'].message_type = _HIVEJOB
_JOB.fields_by_name['application_info'].message_type = _APPLICATIONINFO
_JOB_STATUS.containing_type = _JOB
_JOB.oneofs_by_name['job_spec'].fields.append(
  _JOB.fields_by_name['mapreduce_job'])
_JOB.fields_by_name['mapreduce_job'].containing_oneof = _JOB.oneofs_by_name['job_spec']
_JOB.oneofs_by_name['job_spec'].fields.append(
  _JOB.fields_by_name['spark_job'])
_JOB.fields_by_name['spark_job'].containing_oneof = _JOB.oneofs_by_name['job_spec']
_JOB.oneofs_by_name['job_spec'].fields.append(
  _JOB.fields_by_name['pyspark_job'])
_JOB.fields_by_name['pyspark_job'].containing_oneof = _JOB.oneofs_by_name['job_spec']
_JOB.oneofs_by_name['job_spec'].fields.append(
  _JOB.fields_by_name['hive_job'])
_JOB.fields_by_name['hive_job'].containing_oneof = _JOB.oneofs_by_name['job_spec']
_APPLICATIONINFO.fields_by_name['application_attempts'].message_type = _APPLICATIONATTEMPT
_MAPREDUCEJOB_PROPERTIESENTRY.containing_type = _MAPREDUCEJOB
_MAPREDUCEJOB.fields_by_name['properties'].message_type = _MAPREDUCEJOB_PROPERTIESENTRY
_MAPREDUCEJOB.oneofs_by_name['driver'].fields.append(
  _MAPREDUCEJOB.fields_by_name['main_jar_file_uri'])
_MAPREDUCEJOB.fields_by_name['main_jar_file_uri'].containing_oneof = _MAPREDUCEJOB.oneofs_by_name['driver']
_MAPREDUCEJOB.oneofs_by_name['driver'].fields.append(
  _MAPREDUCEJOB.fields_by_name['main_class'])
_MAPREDUCEJOB.fields_by_name['main_class'].containing_oneof = _MAPREDUCEJOB.oneofs_by_name['driver']
_SPARKJOB_PROPERTIESENTRY.containing_type = _SPARKJOB
_SPARKJOB.fields_by_name['properties'].message_type = _SPARKJOB_PROPERTIESENTRY
_PYSPARKJOB_PROPERTIESENTRY.containing_type = _PYSPARKJOB
_PYSPARKJOB.fields_by_name['properties'].message_type = _PYSPARKJOB_PROPERTIESENTRY
_HIVEJOB_PROPERTIESENTRY.containing_type = _HIVEJOB
_HIVEJOB_SCRIPTVARIABLESENTRY.containing_type = _HIVEJOB
_HIVEJOB.fields_by_name['properties'].message_type = _HIVEJOB_PROPERTIESENTRY
_HIVEJOB.fields_by_name['script_variables'].message_type = _HIVEJOB_SCRIPTVARIABLESENTRY
_HIVEJOB.fields_by_name['query_list'].message_type = _QUERYLIST
_HIVEJOB.oneofs_by_name['query_type'].fields.append(
  _HIVEJOB.fields_by_name['query_file_uri'])
_HIVEJOB.fields_by_name['query_file_uri'].containing_oneof = _HIVEJOB.oneofs_by_name['query_type']
_HIVEJOB.oneofs_by_name['query_type'].fields.append(
  _HIVEJOB.fields_by_name['query_list'])
_HIVEJOB.fields_by_name['query_list'].containing_oneof = _HIVEJOB.oneofs_by_name['query_type']
DESCRIPTOR.message_types_by_name['Job'] = _JOB
DESCRIPTOR.message_types_by_name['ApplicationAttempt'] = _APPLICATIONATTEMPT
DESCRIPTOR.message_types_by_name['ApplicationInfo'] = _APPLICATIONINFO
DESCRIPTOR.message_types_by_name['MapreduceJob'] = _MAPREDUCEJOB
DESCRIPTOR.message_types_by_name['SparkJob'] = _SPARKJOB
DESCRIPTOR.message_types_by_name['PysparkJob'] = _PYSPARKJOB
DESCRIPTOR.message_types_by_name['QueryList'] = _QUERYLIST
DESCRIPTOR.message_types_by_name['HiveJob'] = _HIVEJOB
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), {
  'DESCRIPTOR' : _JOB,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.Job)
  })
_sym_db.RegisterMessage(Job)

ApplicationAttempt = _reflection.GeneratedProtocolMessageType('ApplicationAttempt', (_message.Message,), {
  'DESCRIPTOR' : _APPLICATIONATTEMPT,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.ApplicationAttempt)
  })
_sym_db.RegisterMessage(ApplicationAttempt)

ApplicationInfo = _reflection.GeneratedProtocolMessageType('ApplicationInfo', (_message.Message,), {
  'DESCRIPTOR' : _APPLICATIONINFO,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.ApplicationInfo)
  })
_sym_db.RegisterMessage(ApplicationInfo)

MapreduceJob = _reflection.GeneratedProtocolMessageType('MapreduceJob', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPREDUCEJOB_PROPERTIESENTRY,
    '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.MapreduceJob.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _MAPREDUCEJOB,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.MapreduceJob)
  })
_sym_db.RegisterMessage(MapreduceJob)
_sym_db.RegisterMessage(MapreduceJob.PropertiesEntry)

SparkJob = _reflection.GeneratedProtocolMessageType('SparkJob', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPARKJOB_PROPERTIESENTRY,
    '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.SparkJob.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _SPARKJOB,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.SparkJob)
  })
_sym_db.RegisterMessage(SparkJob)
_sym_db.RegisterMessage(SparkJob.PropertiesEntry)

PysparkJob = _reflection.GeneratedProtocolMessageType('PysparkJob', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _PYSPARKJOB_PROPERTIESENTRY,
    '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.PysparkJob.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _PYSPARKJOB,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.PysparkJob)
  })
_sym_db.RegisterMessage(PysparkJob)
_sym_db.RegisterMessage(PysparkJob.PropertiesEntry)

QueryList = _reflection.GeneratedProtocolMessageType('QueryList', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLIST,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.QueryList)
  })
_sym_db.RegisterMessage(QueryList)

HiveJob = _reflection.GeneratedProtocolMessageType('HiveJob', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HIVEJOB_PROPERTIESENTRY,
    '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.HiveJob.PropertiesEntry)
    })
  ,

  'ScriptVariablesEntry' : _reflection.GeneratedProtocolMessageType('ScriptVariablesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HIVEJOB_SCRIPTVARIABLESENTRY,
    '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.HiveJob.ScriptVariablesEntry)
    })
  ,
  'DESCRIPTOR' : _HIVEJOB,
  '__module__' : 'yandex.cloud.dataproc.manager.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.manager.v1.HiveJob)
  })
_sym_db.RegisterMessage(HiveJob)
_sym_db.RegisterMessage(HiveJob.PropertiesEntry)
_sym_db.RegisterMessage(HiveJob.ScriptVariablesEntry)


DESCRIPTOR._options = None
_MAPREDUCEJOB_PROPERTIESENTRY._options = None
_SPARKJOB_PROPERTIESENTRY._options = None
_PYSPARKJOB_PROPERTIESENTRY._options = None
_HIVEJOB_PROPERTIESENTRY._options = None
_HIVEJOB_SCRIPTVARIABLESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v1/app_token_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datasphere/v1/app_token_service.proto',
  package='yandex.cloud.datasphere.v1',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2yandex/cloud/datasphere/v1/app_token_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"(\n\x17\x41ppTokenValidateRequest\x12\r\n\x05token\x18\x01 \x01(\t2\x9e\x01\n\x0f\x41ppTokenService\x12\x8a\x01\n\x08Validate\x12\x33.yandex.cloud.datasphere.v1.AppTokenValidateRequest\x1a\x16.google.protobuf.Empty\"1\x82\xd3\xe4\x93\x02+\")/datasphere/v1/appTokens/{token}:validateBk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_APPTOKENVALIDATEREQUEST = _descriptor.Descriptor(
  name='AppTokenValidateRequest',
  full_name='yandex.cloud.datasphere.v1.AppTokenValidateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='yandex.cloud.datasphere.v1.AppTokenValidateRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=181,
)

DESCRIPTOR.message_types_by_name['AppTokenValidateRequest'] = _APPTOKENVALIDATEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AppTokenValidateRequest = _reflection.GeneratedProtocolMessageType('AppTokenValidateRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPTOKENVALIDATEREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.app_token_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.AppTokenValidateRequest)
  })
_sym_db.RegisterMessage(AppTokenValidateRequest)


DESCRIPTOR._options = None

_APPTOKENSERVICE = _descriptor.ServiceDescriptor(
  name='AppTokenService',
  full_name='yandex.cloud.datasphere.v1.AppTokenService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=184,
  serialized_end=342,
  methods=[
  _descriptor.MethodDescriptor(
    name='Validate',
    full_name='yandex.cloud.datasphere.v1.AppTokenService.Validate',
    index=0,
    containing_service=None,
    input_type=_APPTOKENVALIDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002+\")/datasphere/v1/appTokens/{token}:validate',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_APPTOKENSERVICE)

DESCRIPTOR.services_by_name['AppTokenService'] = _APPTOKENSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iot/devices/v1/device.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iot/devices/v1/device.proto',
  package='yandex.cloud.iot.devices.v1',
  syntax='proto3',
  serialized_options=b'\n\037yandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devices',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(yandex/cloud/iot/devices/v1/device.proto\x12\x1byandex.cloud.iot.devices.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xd1\x03\n\x06\x44\x65vice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bregistry_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12L\n\rtopic_aliases\x18\x06 \x03(\x0b\x32\x35.yandex.cloud.iot.devices.v1.Device.TopicAliasesEntry\x12:\n\x06status\x18\x07 \x01(\x0e\x32*.yandex.cloud.iot.devices.v1.Device.Status\x12J\n\x0fmonitoring_data\x18\x08 \x01(\x0b\x32\x31.yandex.cloud.iot.devices.v1.DeviceMonitoringData\x1a\x33\n\x11TopicAliasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\"\x85\x01\n\x11\x44\x65viceCertificate\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\x18\n\x10\x63\x65rtificate_data\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"_\n\x0e\x44\x65vicePassword\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8e\x02\n\x14\x44\x65viceMonitoringData\x12\x14\n\x0clast_auth_ip\x18\x01 \x01(\t\x12\x32\n\x0elast_auth_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_pub_activity_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16last_sub_activity_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_online_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*!\n\nDeviceView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x42j\n\x1fyandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devicesb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_DEVICEVIEW = _descriptor.EnumDescriptor(
  name='DeviceView',
  full_name='yandex.cloud.iot.devices.v1.DeviceView',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1111,
  serialized_end=1144,
)
_sym_db.RegisterEnumDescriptor(_DEVICEVIEW)

DeviceView = enum_type_wrapper.EnumTypeWrapper(_DEVICEVIEW)
BASIC = 0
FULL = 1


_DEVICE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.iot.devices.v1.Device.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=531,
  serialized_end=603,
)
_sym_db.RegisterEnumDescriptor(_DEVICE_STATUS)


_DEVICE_TOPICALIASESENTRY = _descriptor.Descriptor(
  name='TopicAliasesEntry',
  full_name='yandex.cloud.iot.devices.v1.Device.TopicAliasesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.iot.devices.v1.Device.TopicAliasesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.iot.devices.v1.Device.TopicAliasesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=529,
)

_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='yandex.cloud.iot.devices.v1.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.iot.devices.v1.Device.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registry_id', full_name='yandex.cloud.iot.devices.v1.Device.registry_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.iot.devices.v1.Device.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.iot.devices.v1.Device.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iot.devices.v1.Device.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_aliases', full_name='yandex.cloud.iot.devices.v1.Device.topic_aliases', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.iot.devices.v1.Device.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring_data', full_name='yandex.cloud.iot.devices.v1.Device.monitoring_data', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEVICE_TOPICALIASESENTRY, ],
  enum_types=[
    _DEVICE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=603,
)


_DEVICECERTIFICATE = _descriptor.Descriptor(
  name='DeviceCertificate',
  full_name='yandex.cloud.iot.devices.v1.DeviceCertificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='yandex.cloud.iot.devices.v1.DeviceCertificate.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='yandex.cloud.iot.devices.v1.DeviceCertificate.fingerprint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_data', full_name='yandex.cloud.iot.devices.v1.DeviceCertificate.certificate_data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.iot.devices.v1.DeviceCertificate.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=606,
  serialized_end=739,
)


_DEVICEPASSWORD = _descriptor.Descriptor(
  name='DevicePassword',
  full_name='yandex.cloud.iot.devices.v1.DevicePassword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='yandex.cloud.iot.devices.v1.DevicePassword.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.iot.devices.v1.DevicePassword.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.iot.devices.v1.DevicePassword.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=836,
)


_DEVICEMONITORINGDATA = _descriptor.Descriptor(
  name='DeviceMonitoringData',
  full_name='yandex.cloud.iot.devices.v1.DeviceMonitoringData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_auth_ip', full_name='yandex.cloud.iot.devices.v1.DeviceMonitoringData.last_auth_ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_auth_time', full_name='yandex.cloud.iot.devices.v1.DeviceMonitoringData.last_auth_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_pub_activity_time', full_name='yandex.cloud.iot.devices.v1.DeviceMonitoringData.last_pub_activity_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_sub_activity_time', full_name='yandex.cloud.iot.devices.v1.DeviceMonitoringData.last_sub_activity_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_online_time', full_name='yandex.cloud.iot.devices.v1.DeviceMonitoringData.last_online_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=839,
  serialized_end=1109,
)

_DEVICE_TOPICALIASESENTRY.containing_type = _DEVICE
_DEVICE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DEVICE.fields_by_name['topic_aliases'].message_type = _DEVICE_TOPICALIASESENTRY
_DEVICE.fields_by_name['status'].enum_type = _DEVICE_STATUS
_DEVICE.fields_by_name['monitoring_data'].message_type = _DEVICEMONITORINGDATA
_DEVICE_STATUS.containing_type = _DEVICE
_DEVICECERTIFICATE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DEVICEPASSWORD.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DEVICEMONITORINGDATA.fields_by_name['last_auth_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DEVICEMONITORINGDATA.fields_by_name['last_pub_activity_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DEVICEMONITORINGDATA.fields_by_name['last_sub_activity_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DEVICEMONITORINGDATA.fields_by_name['last_online_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Device'] = _DEVICE
DESCRIPTOR.message_types_by_name['DeviceCertificate'] = _DEVICECERTIFICATE
DESCRIPTOR.message_types_by_name['DevicePassword'] = _DEVICEPASSWORD
DESCRIPTOR.message_types_by_name['DeviceMonitoringData'] = _DEVICEMONITORINGDATA
DESCRIPTOR.enum_types_by_name['DeviceView'] = _DEVICEVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {

  'TopicAliasesEntry' : _reflection.GeneratedProtocolMessageType('TopicAliasesEntry', (_message.Message,), {
    'DESCRIPTOR' : _DEVICE_TOPICALIASESENTRY,
    '__module__' : 'yandex.cloud.iot.devices.v1.device_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.Device.TopicAliasesEntry)
    })
  ,
  'DESCRIPTOR' : _DEVICE,
  '__module__' : 'yandex.cloud.iot.devices.v1.device_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.Device)
  })
_sym_db.RegisterMessage(Device)
_sym_db.RegisterMessage(Device.TopicAliasesEntry)

DeviceCertificate = _reflection.GeneratedProtocolMessageType('DeviceCertificate', (_message.Message,), {
  'DESCRIPTOR' : _DEVICECERTIFICATE,
  '__module__' : 'yandex.cloud.iot.devices.v1.device_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.DeviceCertificate)
  })
_sym_db.RegisterMessage(DeviceCertificate)

DevicePassword = _reflection.GeneratedProtocolMessageType('DevicePassword', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEPASSWORD,
  '__module__' : 'yandex.cloud.iot.devices.v1.device_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.DevicePassword)
  })
_sym_db.RegisterMessage(DevicePassword)

DeviceMonitoringData = _reflection.GeneratedProtocolMessageType('DeviceMonitoringData', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEMONITORINGDATA,
  '__module__' : 'yandex.cloud.iot.devices.v1.device_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.DeviceMonitoringData)
  })
_sym_db.RegisterMessage(DeviceMonitoringData)


DESCRIPTOR._options = None
_DEVICE_TOPICALIASESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v1/node_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datasphere/v1/node_service.proto',
  package='yandex.cloud.datasphere.v1',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/datasphere/v1/node_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\"b\n\x14NodeExecutionRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\t\x12&\n\x05input\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"@\n\x15NodeExecutionResponse\x12\'\n\x06output\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xb1\x01\n\x0bNodeService\x12\xa1\x01\n\x07\x45xecute\x12\x30.yandex.cloud.datasphere.v1.NodeExecutionRequest\x1a\x31.yandex.cloud.datasphere.v1.NodeExecutionResponse\"1\x82\xd3\xe4\x93\x02+\"&/datasphere/v1/nodes/{node_id}:execute:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_NODEEXECUTIONREQUEST = _descriptor.Descriptor(
  name='NodeExecutionRequest',
  full_name='yandex.cloud.datasphere.v1.NodeExecutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.datasphere.v1.NodeExecutionRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='yandex.cloud.datasphere.v1.NodeExecutionRequest.node_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input', full_name='yandex.cloud.datasphere.v1.NodeExecutionRequest.input', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=235,
)


_NODEEXECUTIONRESPONSE = _descriptor.Descriptor(
  name='NodeExecutionResponse',
  full_name='yandex.cloud.datasphere.v1.NodeExecutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output', full_name='yandex.cloud.datasphere.v1.NodeExecutionResponse.output', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=301,
)

_NODEEXECUTIONREQUEST.fields_by_name['input'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_NODEEXECUTIONRESPONSE.fields_by_name['output'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['NodeExecutionRequest'] = _NODEEXECUTIONREQUEST
DESCRIPTOR.message_types_by_name['NodeExecutionResponse'] = _NODEEXECUTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NodeExecutionRequest = _reflection.GeneratedProtocolMessageType('NodeExecutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODEEXECUTIONREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.node_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.NodeExecutionRequest)
  })
_sym_db.RegisterMessage(NodeExecutionRequest)

NodeExecutionResponse = _reflection.GeneratedProtocolMessageType('NodeExecutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODEEXECUTIONRESPONSE,
  '__module__' : 'yandex.cloud.datasphere.v1.node_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.NodeExecutionResponse)
  })
_sym_db.RegisterMessage(NodeExecutionResponse)


DESCRIPTOR._options = None

_NODESERVICE = _descriptor.ServiceDescriptor(
  name='NodeService',
  full_name='yandex.cloud.datasphere.v1.NodeService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=304,
  serialized_end=481,
  methods=[
  _descriptor.MethodDescriptor(
    name='Execute',
    full_name='yandex.cloud.datasphere.v1.NodeService.Execute',
    index=0,
    containing_service=None,
    input_type=_NODEEXECUTIONREQUEST,
    output_type=_NODEEXECUTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002+\"&/datasphere/v1/nodes/{node_id}:execute:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NODESERVICE)

DESCRIPTOR.services_by_name['NodeService'] = _NODESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/v1/maintenance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import dayofweek_pb2 as google_dot_type_dot_dayofweek__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/k8s/v1/maintenance.proto',
  package='yandex.cloud.k8s.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%yandex/cloud/k8s/v1/maintenance.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1bgoogle/type/dayofweek.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dyandex/cloud/validation.proto\"\x89\x02\n\x11MaintenanceWindow\x12@\n\x07\x61nytime\x18\x01 \x01(\x0b\x32-.yandex.cloud.k8s.v1.AnytimeMaintenanceWindowH\x00\x12O\n\x18\x64\x61ily_maintenance_window\x18\x02 \x01(\x0b\x32+.yandex.cloud.k8s.v1.DailyMaintenanceWindowH\x00\x12Q\n\x19weekly_maintenance_window\x18\x03 \x01(\x0b\x32,.yandex.cloud.k8s.v1.WeeklyMaintenanceWindowH\x00\x42\x0e\n\x06policy\x12\x04\xc0\xc1\x31\x01\"\x1a\n\x18\x41nytimeMaintenanceWindow\"\x83\x01\n\x16\x44\x61ilyMaintenanceWindow\x12\x30\n\nstart_time\x18\x01 \x01(\x0b\x32\x16.google.type.TimeOfDayB\x04\xe8\xc7\x31\x01\x12\x37\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31h-24h\"\xb7\x01\n\x1b\x44\x61ysOfWeekMaintenanceWindow\x12-\n\x04\x64\x61ys\x18\x01 \x03(\x0e\x32\x16.google.type.DayOfWeekB\x07\x82\xc8\x31\x03\x31-7\x12\x30\n\nstart_time\x18\x02 \x01(\x0b\x32\x16.google.type.TimeOfDayB\x04\xe8\xc7\x31\x01\x12\x37\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31h-24h\"j\n\x17WeeklyMaintenanceWindow\x12O\n\x0c\x64\x61ys_of_week\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.k8s.v1.DaysOfWeekMaintenanceWindowB\x07\x82\xc8\x31\x03\x31-7BV\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_dayofweek__pb2.DESCRIPTOR,google_dot_type_dot_timeofday__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_MAINTENANCEWINDOW = _descriptor.Descriptor(
  name='MaintenanceWindow',
  full_name='yandex.cloud.k8s.v1.MaintenanceWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='anytime', full_name='yandex.cloud.k8s.v1.MaintenanceWindow.anytime', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='daily_maintenance_window', full_name='yandex.cloud.k8s.v1.MaintenanceWindow.daily_maintenance_window', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weekly_maintenance_window', full_name='yandex.cloud.k8s.v1.MaintenanceWindow.weekly_maintenance_window', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='policy', full_name='yandex.cloud.k8s.v1.MaintenanceWindow.policy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=184,
  serialized_end=449,
)


_ANYTIMEMAINTENANCEWINDOW = _descriptor.Descriptor(
  name='AnytimeMaintenanceWindow',
  full_name='yandex.cloud.k8s.v1.AnytimeMaintenanceWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=477,
)


_DAILYMAINTENANCEWINDOW = _descriptor.Descriptor(
  name='DailyMaintenanceWindow',
  full_name='yandex.cloud.k8s.v1.DailyMaintenanceWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time', full_name='yandex.cloud.k8s.v1.DailyMaintenanceWindow.start_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='yandex.cloud.k8s.v1.DailyMaintenanceWindow.duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0061h-24h', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=611,
)


_DAYSOFWEEKMAINTENANCEWINDOW = _descriptor.Descriptor(
  name='DaysOfWeekMaintenanceWindow',
  full_name='yandex.cloud.k8s.v1.DaysOfWeekMaintenanceWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='days', full_name='yandex.cloud.k8s.v1.DaysOfWeekMaintenanceWindow.days', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0031-7', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='yandex.cloud.k8s.v1.DaysOfWeekMaintenanceWindow.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='yandex.cloud.k8s.v1.DaysOfWeekMaintenanceWindow.duration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0061h-24h', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=797,
)


_WEEKLYMAINTENANCEWINDOW = _descriptor.Descriptor(
  name='WeeklyMaintenanceWindow',
  full_name='yandex.cloud.k8s.v1.WeeklyMaintenanceWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='days_of_week', full_name='yandex.cloud.k8s.v1.WeeklyMaintenanceWindow.days_of_week', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0031-7', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=799,
  serialized_end=905,
)

_MAINTENANCEWINDOW.fields_by_name['anytime'].message_type = _ANYTIMEMAINTENANCEWINDOW
_MAINTENANCEWINDOW.fields_by_name['daily_maintenance_window'].message_type = _DAILYMAINTENANCEWINDOW
_MAINTENANCEWINDOW.fields_by_name['weekly_maintenance_window'].message_type = _WEEKLYMAINTENANCEWINDOW
_MAINTENANCEWINDOW.oneofs_by_name['policy'].fields.append(
  _MAINTENANCEWINDOW.fields_by_name['anytime'])
_MAINTENANCEWINDOW.fields_by_name['anytime'].containing_oneof = _MAINTENANCEWINDOW.oneofs_by_name['policy']
_MAINTENANCEWINDOW.oneofs_by_name['policy'].fields.append(
  _MAINTENANCEWINDOW.fields_by_name['daily_maintenance_window'])
_MAINTENANCEWINDOW.fields_by_name['daily_maintenance_window'].containing_oneof = _MAINTENANCEWINDOW.oneofs_by_name['policy']
_MAINTENANCEWINDOW.oneofs_by_name['policy'].fields.append(
  _MAINTENANCEWINDOW.fields_by_name['weekly_maintenance_window'])
_MAINTENANCEWINDOW.fields_by_name['weekly_maintenance_window'].containing_oneof = _MAINTENANCEWINDOW.oneofs_by_name['policy']
_DAILYMAINTENANCEWINDOW.fields_by_name['start_time'].message_type = google_dot_type_dot_timeofday__pb2._TIMEOFDAY
_DAILYMAINTENANCEWINDOW.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DAYSOFWEEKMAINTENANCEWINDOW.fields_by_name['days'].enum_type = google_dot_type_dot_dayofweek__pb2._DAYOFWEEK
_DAYSOFWEEKMAINTENANCEWINDOW.fields_by_name['start_time'].message_type = google_dot_type_dot_timeofday__pb2._TIMEOFDAY
_DAYSOFWEEKMAINTENANCEWINDOW.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WEEKLYMAINTENANCEWINDOW.fields_by_name['days_of_week'].message_type = _DAYSOFWEEKMAINTENANCEWINDOW
DESCRIPTOR.message_types_by_name['MaintenanceWindow'] = _MAINTENANCEWINDOW
DESCRIPTOR.message_types_by_name['AnytimeMaintenanceWindow'] = _ANYTIMEMAINTENANCEWINDOW
DESCRIPTOR.message_types_by_name['DailyMaintenanceWindow'] = _DAILYMAINTENANCEWINDOW
DESCRIPTOR.message_types_by_name['DaysOfWeekMaintenanceWindow'] = _DAYSOFWEEKMAINTENANCEWINDOW
DESCRIPTOR.message_types_by_name['WeeklyMaintenanceWindow'] = _WEEKLYMAINTENANCEWINDOW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MaintenanceWindow = _reflection.GeneratedProtocolMessageType('MaintenanceWindow', (_message.Message,), {
  'DESCRIPTOR' : _MAINTENANCEWINDOW,
  '__module__' : 'yandex.cloud.k8s.v1.maintenance_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.MaintenanceWindow)
  })
_sym_db.RegisterMessage(MaintenanceWindow)

AnytimeMaintenanceWindow = _reflection.GeneratedProtocolMessageType('AnytimeMaintenanceWindow', (_message.Message,), {
  'DESCRIPTOR' : _ANYTIMEMAINTENANCEWINDOW,
  '__module__' : 'yandex.cloud.k8s.v1.maintenance_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.AnytimeMaintenanceWindow)
  })
_sym_db.RegisterMessage(AnytimeMaintenanceWindow)

DailyMaintenanceWindow = _reflection.GeneratedProtocolMessageType('DailyMaintenanceWindow', (_message.Message,), {
  'DESCRIPTOR' : _DAILYMAINTENANCEWINDOW,
  '__module__' : 'yandex.cloud.k8s.v1.maintenance_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.DailyMaintenanceWindow)
  })
_sym_db.RegisterMessage(DailyMaintenanceWindow)

DaysOfWeekMaintenanceWindow = _reflection.GeneratedProtocolMessageType('DaysOfWeekMaintenanceWindow', (_message.Message,), {
  'DESCRIPTOR' : _DAYSOFWEEKMAINTENANCEWINDOW,
  '__module__' : 'yandex.cloud.k8s.v1.maintenance_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.DaysOfWeekMaintenanceWindow)
  })
_sym_db.RegisterMessage(DaysOfWeekMaintenanceWindow)

WeeklyMaintenanceWindow = _reflection.GeneratedProtocolMessageType('WeeklyMaintenanceWindow', (_message.Message,), {
  'DESCRIPTOR' : _WEEKLYMAINTENANCEWINDOW,
  '__module__' : 'yandex.cloud.k8s.v1.maintenance_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.k8s.v1.WeeklyMaintenanceWindow)
  })
_sym_db.RegisterMessage(WeeklyMaintenanceWindow)


DESCRIPTOR._options = None
_MAINTENANCEWINDOW.oneofs_by_name['policy']._options = None
_DAILYMAINTENANCEWINDOW.fields_by_name['start_time']._options = None
_DAILYMAINTENANCEWINDOW.fields_by_name['duration']._options = None
_DAYSOFWEEKMAINTENANCEWINDOW.fields_by_name['days']._options = None
_DAYSOFWEEKMAINTENANCEWINDOW.fields_by_name['start_time']._options = None
_DAYSOFWEEKMAINTENANCEWINDOW.fields_by_name['duration']._options = None
_WEEKLYMAINTENANCEWINDOW.fields_by_name['days_of_week']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/tts/v3/tts_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.tts.v3 import tts_pb2 as yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/tts/v3/tts_service.proto',
  package='speechkit.tts.v3',
  syntax='proto3',
  serialized_options=b'\n\032yandex.cloud.api.ai.tts.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/tts/v3;tts',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(yandex/cloud/ai/tts/v3/tts_service.proto\x12\x10speechkit.tts.v3\x1a yandex/cloud/ai/tts/v3/tts.proto2\x82\x01\n\x0bSynthesizer\x12s\n\x12UtteranceSynthesis\x12+.speechkit.tts.v3.UtteranceSynthesisRequest\x1a,.speechkit.tts.v3.UtteranceSynthesisResponse\"\x00\x30\x01\x42\\\n\x1ayandex.cloud.api.ai.tts.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/tts/v3;ttsb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_SYNTHESIZER = _descriptor.ServiceDescriptor(
  name='Synthesizer',
  full_name='speechkit.tts.v3.Synthesizer',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=97,
  serialized_end=227,
  methods=[
  _descriptor.MethodDescriptor(
    name='UtteranceSynthesis',
    full_name='speechkit.tts.v3.Synthesizer.UtteranceSynthesis',
    index=0,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2._UTTERANCESYNTHESISREQUEST,
    output_type=yandex_dot_cloud_dot_ai_dot_tts_dot_v3_dot_tts__pb2._UTTERANCESYNTHESISRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SYNTHESIZER)

DESCRIPTOR.services_by_name['Synthesizer'] = _SYNTHESIZER

# @@protoc_insertion_point(module_scope)
